'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NullRouter = exports.ExpressRouter = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _connectMultiparty = require('connect-multiparty');

var _connectMultiparty2 = _interopRequireDefault(_connectMultiparty);

var _scopedHttpClient = require('scoped-http-client');

var HttpClient = _interopRequireWildcard(_scopedHttpClient);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var NullRouter =
/**
 * Setup an empty router object
 *
 * returns nothing
 */
function NullRouter(robot) {
  _classCallCheck(this, NullRouter);

  var msg = 'A script has tried registering a HTTP route while the HTTP ' + 'server is disabled with --disabled-httpd.';
  robot.router = {
    get: function get() {
      return robot.logger.warning(msg);
    },
    post: function post() {
      return robot.logger.warning(msg);
    },
    put: function put() {
      return robot.logger.warning(msg);
    },
    delete: function _delete() {
      return robot.logger.warning(msg);
    }
  };
};

var ExpressRouter = function () {
  /**
   * Setup the Express server's defaults.
   *
   * Returns nothing.
   */

  function ExpressRouter(robot) {
    _classCallCheck(this, ExpressRouter);

    var user = process.env.EXPRESS_USER;
    var pass = process.env.EXPRESS_PASSWORD;
    var stat = process.env.EXPRESS_STATIC;
    var port = process.env.EXPRESS_PORT || process.env.PORT || 8080;
    var address = process.env.EXPRESS_BIND_ADDRESS || process.env.BIND_ADDRESS || '0.0.0.0';

    var app = (0, _express2.default)();

    app.use(function (req, res, next) {
      res.setHeader('X-Powered-By', 'webby/' + robot.name);
      next();
    });

    if (user && pass) {
      app.use(_express2.default.basicAuth(user, pass));
    }
    app.use(_express2.default.query());

    app.use(_express2.default.json());
    app.use(_express2.default.urlencoded());
    // replacement for deprecated express.multipart/connect.multipart
    // limit to 100mb, as per the old behavior
    app.use((0, _connectMultiparty2.default)({
      maxFilesSize: 100 * 1024 * 1024
    }));

    if (stat) {
      app.use(_express2.default.static(stat));
    }

    try {
      robot.server = app.listen(port, address);
      robot.router = app;
    } catch (error) {
      robot.logger.error('Error trying to start HTTP server: ' + error + '\n\n        ' + error.stack);
      process.exit(1);
    }

    this.setupHeroku(robot);
  }

  /**
   * keep bot alive if runtime environment is heroku
   */


  _createClass(ExpressRouter, [{
    key: 'setupHeroku',
    value: function setupHeroku(robot) {
      var herokuUrl = process.env.HEROKU_URL;

      if (herokuUrl) {
        if (!/\/$/.test(herokuUrl)) {
          herokuUrl += '/';
        }
        setInterval(function () {
          HttpClient.create(herokuUrl + 'hubot/ping').post(function (err, res, body) {
            robot.logger.info('keep alive ping!');
          });
        }, 5 * 60 * 1000);
      }
    }
  }]);

  return ExpressRouter;
}();

exports.ExpressRouter = ExpressRouter;
exports.NullRouter = NullRouter;